/********************************************************************
 * Copyright (C) 2005 Piotr Pszczolkowski
 *-------------------------------------------------------------------
 * This file is part of BsC (Beesoft Commander).
 *
 * BsC is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * BsC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with BsC; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *******************************************************************/

/*------- include files:
-------------------------------------------------------------------*/
#include "Console.h"
#include <qlayout.h>
#include <qtextedit.h>
#include <qlineedit.h>
#include <qprocess.h>
#include <qdir.h>


/*------- local constants:
-------------------------------------------------------------------*/
const int  Console::OVER_STRETCH                     = 100;
const QRgb Console::BROWSER_DEFAULT_TEXT_COLOR       = qRgb( 255, 255, 255 );
const QRgb Console::BROWSER_DEFAULT_BACKGROUND_COLOR = qRgb( 88, 88, 88 );
const QRgb Console::CMD_DEFAULT_TEXT_COLOR           = BROWSER_DEFAULT_TEXT_COLOR;
const QRgb Console::CMD_DEFAULT_BACKGROUND_COLOR     = BROWSER_DEFAULT_BACKGROUND_COLOR;


//*******************************************************************
// Console
//*******************************************************************
Console::Console( QWidget* const in_parent )
: QFrame            ( in_parent )
, d_browser         ( new QTextEdit( this ))
, d_cmd             ( new QLineEdit( this ))
, d_browser_fg_color( BROWSER_DEFAULT_TEXT_COLOR )
, d_browser_bg_color( BROWSER_DEFAULT_BACKGROUND_COLOR )
, d_cmd_fg_color    ( CMD_DEFAULT_TEXT_COLOR )
, d_cmd_bg_color    ( CMD_DEFAULT_BACKGROUND_COLOR )
, d_process         ( new QProcess( this ))
, d_ready           ( TRUE )
{
	QVBoxLayout* const main_layout = new QVBoxLayout( this );
	if( main_layout ) {
		d_browser->setReadOnly( TRUE );
		d_browser->setWordWrap( QTextEdit::NoWrap );
		d_browser->setColor( d_browser_fg_color );
		d_browser->setPaper( d_browser_bg_color );

		d_cmd->setPaletteForegroundColor( d_cmd_fg_color );
		d_cmd->setPaletteBackgroundColor( d_cmd_bg_color );
		connect( d_cmd, SIGNAL( returnPressed() ), this, SLOT( return_pressed() ));
			
		main_layout->addWidget( d_browser );
		main_layout->addWidget( d_cmd );
		main_layout->setStretchFactor( d_browser, OVER_STRETCH );

		connect( d_process, SIGNAL( readyReadStdout() ), this, SLOT( read_from_stdout() ));
		connect( d_process, SIGNAL( readyReadStderr() ), this, SLOT( read_from_stderr() ));
		connect( d_process, SIGNAL( processExited()   ), this, SLOT( process_exited()   ));
	}
}
// end of Console

//*******************************************************************
// ~Console
//*******************************************************************
Console::~Console()
{
	if( d_process ) {
		delete d_process;
		d_process = 0;
	}
}
// end of ~Console

//*******************************************************************
// showEvent                                                 PRIVATE
//*******************************************************************
void Console::showEvent( QShowEvent* e )
{
	d_cmd->setFocus();
	QFrame::showEvent( e );
}
// end of showEvent

//*******************************************************************
// return_pressed                                       PRIVATE SLOT
//*******************************************************************
void Console::return_pressed()
{
	if( d_ready ) {
		const QString command = d_cmd->text();
		d_cmd->setText( "" );
		
		if( FALSE == command.isEmpty()) {
			d_ready = FALSE;
			d_process->setWorkingDirectory( QDir::current() );
			d_process->clearArguments();
			d_process->addArgument( "bash" );
			d_process->addArgument( "-c" );
			d_process->addArgument( command );
			d_process->start();
		}
	}
}
// end of return_pressed

//*******************************************************************
// read_from_stdout                                     PRIVATE SLOT
//*******************************************************************
void Console::read_from_stdout()
{
	d_browser->append( d_process->readStdout() );
}
// end of read_from_stdout

//*******************************************************************
// read_from_stderr                                     PRIVATE SLOT
//*******************************************************************
void Console::read_from_stderr()
{
	d_browser->append( d_process->readStderr() );
}
// end of read_from_stderr

//*******************************************************************
// process_exited                                       PRIVATE SLOT
//*******************************************************************
void Console::process_exited()
{
	d_ready = TRUE;	
	d_cmd->setFocus();
}
// end of process_exited
