/********************************************************************
 * Copyright (C) 2005, 2006 Piotr Pszczolkowski
 *-------------------------------------------------------------------
 * This file is part of BSCommander (Beesoft Commander).
 *
 * BsC is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * BsC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with BsC; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *******************************************************************/

/*------- include files:
-------------------------------------------------------------------*/
#include "FtpServer.h"
#include "Shared.h"
#include "Config.h"
#include <qlayout.h>
#include <qpushbutton.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qvalidator.h>

/*------- local constants:
-------------------------------------------------------------------*/
const int     FtpServer::OVER_STRETCH  = 100;
const int     FtpServer::SPACING_WIDTH = 2;
const int     FtpServer::MARGIN_WIDTH  = 2;
const QString FtpServer::ANONYM_NAME   = "anonymous";
const QString FtpServer::ANONYM_PASS   = "bsc@beesoft.org";
//...................................................................
const QString FtpServer::CAPTION       = QT_TR_NOOP( "FTP server data" );
const QString FtpServer::BTN_OK        = QT_TR_NOOP( "&Ok" );
const QString FtpServer::SRV_SETTINGS  = QT_TR_NOOP( "Server settings" );
const QString FtpServer::NAME_LABEL    = QT_TR_NOOP( "&Name:" );
const QString FtpServer::PORT_LABEL    = QT_TR_NOOP( "&Port" );
const QString FtpServer::ADDR_LABEL    = QT_TR_NOOP( "&Address:" );
const QString FtpServer::DIR_LABEL     = QT_TR_NOOP( "&Directory:" );
const QString FtpServer::USR_SETTINGS  = QT_TR_NOOP( "User settings" );
const QString FtpServer::USER_LABEL    = QT_TR_NOOP( "&User name:" );
const QString FtpServer::PASS_LABEL    = QT_TR_NOOP( "&Password:" );
const QString FtpServer::ANONYM_CB     = QT_TR_NOOP( "Anonymou&s user" );



//*******************************************************************
// FtpServer                                             CONSTRUCTOR
//*******************************************************************
FtpServer::FtpServer( QWidget* const in_parent, FtpServerInfo& in_fsi )
: QDialog( in_parent )
, d_name_le( 0 )
, d_addr_le( 0 )
, d_port_le( 0 )
, d_dir_le( 0 )
, d_anonym_cb( new QCheckBox( tr(ANONYM_CB), this ))
, d_user_le( 0 )
, d_pass_le( 0 )
, d_validator( new QIntValidator( 1, 100000, this ))
, d_ok_btn( new QPushButton( tr(BTN_OK), this ))
, d_cancel_btn( new QPushButton( tr(Shared::CancelBtnLabel), this ))
, d_fsi( in_fsi )
{
	setCaption( tr(CAPTION) );
	setFont( Config::instance()->lfs_default_font()  );

	connect( d_ok_btn    , SIGNAL( clicked() ), this, SLOT( slot_ok()     ));
	connect( d_cancel_btn, SIGNAL( clicked() ), this, SLOT( slot_cancel() ));
	connect( d_anonym_cb , SIGNAL( toggled(bool) ), this, SLOT( slot_anonym(bool) ));
	
	QHBoxLayout* main_layout = new QHBoxLayout( this );
	main_layout->setSpacing( SPACING_WIDTH );
	main_layout->setMargin( MARGIN_WIDTH );
	
	QVBoxLayout* const data_layout = new QVBoxLayout;
	data_layout->addWidget( make_srv_box() );
	data_layout->addWidget( d_anonym_cb );
	data_layout->addWidget( make_usr_box() );
	main_layout->addLayout( data_layout );

	QVBoxLayout* btn_layout = new QVBoxLayout;
	btn_layout->addStretch( OVER_STRETCH );
	btn_layout->addWidget( d_ok_btn );
	btn_layout->addWidget( d_cancel_btn );
	main_layout->addLayout( btn_layout );
	
	main_layout->setStretchFactor( data_layout, OVER_STRETCH );
}
// end of FtpServer

//*******************************************************************
// ~FtpServer                                             DESTRUCTOR
//*******************************************************************
FtpServer::~FtpServer()
{
	delete d_validator;
	d_validator = 0;
}
// end of ~FtpServer

//*******************************************************************
// polish                                          PRIVATE inherited
//*******************************************************************
void FtpServer::polish()
{
	d_name_le->setText( d_fsi.name() );
	d_addr_le->setText( d_fsi.addr() );
	d_port_le->setText( QString::number( d_fsi.port() ));
	d_dir_le->setText( d_fsi.dir() );
	d_user_le->setText( d_fsi.user() );
	d_pass_le->setText( d_fsi.pass() );
	
	if( ANONYM_NAME == d_fsi.user() ) {
		d_anonym_cb->setChecked( TRUE );
	}

	d_name_le->setFocus();
}
// end of polish

//*******************************************************************
// make_srv_box                                              PRIVATE
//*******************************************************************
QWidget* FtpServer::make_srv_box()
{
	QGroupBox* const gbox = new QGroupBox( 2, Qt::Horizontal, tr(SRV_SETTINGS), this );

	{
		QLabel* const label = new QLabel( tr(NAME_LABEL), gbox );
		d_name_le = new QLineEdit( gbox );
		label->setBuddy( d_name_le );
	}
	{
		QLabel* const label = new QLabel( tr(ADDR_LABEL), gbox );
		d_addr_le = new QLineEdit( gbox );
		label->setBuddy( d_addr_le );
	}
	{
		QLabel* const label = new QLabel( tr(PORT_LABEL), gbox );
		d_port_le = new QLineEdit( gbox );
		d_port_le->setValidator( d_validator );
		label->setBuddy( d_port_le );
	}
	{
		QLabel* const label = new QLabel( tr(DIR_LABEL), gbox );
		d_dir_le = new QLineEdit( gbox );
		label->setBuddy( d_dir_le );
	}

	return gbox;
}
// end of make_srv_box

//*******************************************************************
// make_usr_box                                              PRIVATE
//*******************************************************************
QWidget* FtpServer::make_usr_box()
{
	QGroupBox* const gbox = new QGroupBox( 2, Qt::Horizontal, tr(USR_SETTINGS), this );

	{
		QLabel* const label = new QLabel( tr(USER_LABEL), gbox );
		d_user_le = new QLineEdit( gbox );
		label->setBuddy( d_user_le );
	}
	{
		QLabel* const label = new QLabel( tr(PASS_LABEL), gbox );
		d_pass_le = new QLineEdit( gbox );
		d_pass_le->setEchoMode( QLineEdit::Password );
		label->setBuddy( d_pass_le );
	}

	return gbox;
}
// end of make_usr_box

//*******************************************************************
// check                                                     PRIVATE
//*******************************************************************
bool FtpServer::check()
{
	bool retval = TRUE;
	
	if( d_name_le->text().isEmpty() ) {
		retval = FALSE;
		d_name_le->setFocus();
	}
	else if( d_addr_le->text().isEmpty() ) {
		retval = FALSE;
		d_addr_le->setFocus();
	}
	else if( d_port_le->text().isEmpty() ) {
		retval = FALSE;
		d_port_le->setText( "21" );
		d_port_le->setFocus();
	}
	else if( d_dir_le->text().isEmpty() ) {
		retval = FALSE;
		d_dir_le->setText( "/" );
		d_dir_le->setFocus();
	}
	else if( d_user_le->text().isEmpty() ) {
		retval = FALSE;
		d_user_le->setFocus();
	}
	else if( d_pass_le->text().isEmpty() ) {
		retval = FALSE;
		d_pass_le->setFocus();
	}

	return retval;
}
// end of check

//*******************************************************************
// slot_ok                                              PRIVATE slot
//*******************************************************************
void FtpServer::slot_ok()
{
	if( check() ) {
		d_fsi.set_name( d_name_le->text() );
		d_fsi.set_addr( d_addr_le->text() );
		d_fsi.set_port( d_port_le->text().toInt() );
		d_fsi.set_dir ( d_dir_le->text()  );
		d_fsi.set_user( d_user_le->text() );
		d_fsi.set_pass( d_pass_le->text() );
		accept();
	}
}
// end of slot_ok

//*******************************************************************
// slot_cancel                                          PRIVATE slot
//*******************************************************************
void FtpServer::slot_cancel()
{
	d_fsi.clear();
	reject();
}
// end of slot_cancel

//*******************************************************************
// slot_anonym                                          PRIVATE slot
//*******************************************************************
void FtpServer::slot_anonym( bool in_on )
{
	if( in_on ) {
		d_user_le->setEnabled( FALSE );
		d_pass_le->setEnabled( FALSE );
		d_user_le->setText( ANONYM_NAME );
		d_pass_le->setText( ANONYM_PASS );
	}
	else {
		d_user_le->setEnabled( TRUE );
		d_pass_le->setEnabled( TRUE );
		d_user_le->clear();
		d_pass_le->clear();		
	}
}
// end of slot_anonym
