/********************************************************************
 * Copyright (C) 2005 Piotr Pszczolkowski
 *-------------------------------------------------------------------
 * This file is part of BsC (Beesoft Commander).
 *
 * BsC is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * BsC is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with BsC; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *******************************************************************/

/*------- include files:
-------------------------------------------------------------------*/
#include "RightView.h"
#include "Settings.h"
#include "ViewWindow.h"
#include "Workspace.h"
#include <qlayout.h>
#include <qapplication.h>

/*------- local constants:
-------------------------------------------------------------------*/
const QString RightView::ArgPrefix       = "-rp=";
const QString RightView::ConfigGroupName = "RigthView";

//*******************************************************************
// RightPanel
//*******************************************************************
RightView::RightView( QWidget* const in_parent, Workspace* const in_workspace )
: QFrame( in_parent )
, d_view( new ViewWindow( this ))
{
	QVBoxLayout* const main_layout = new QVBoxLayout( this );
	if( main_layout ) {
		main_layout->addWidget( d_view );
		in_workspace->set_right_view_window( d_view );
	}
	connect( in_workspace, SIGNAL( looks_refresh()  ), d_view      , SLOT( looks_refresh()  ));
	connect( in_workspace, SIGNAL( ftp_start_right()), d_view      , SLOT( slot_ftp_start() ));
	connect( in_workspace, SIGNAL( ftp_end()        ), d_view      , SLOT( slot_ftp_end()   ));
	connect( in_workspace, SIGNAL( filter( bool )   ), d_view      , SLOT( filter( bool )   ));
	connect( in_workspace, SIGNAL( reload()         ), d_view      , SLOT( cd_refresh()     ));
	connect( in_workspace, SIGNAL( select_right()   ), d_view      , SLOT( slot_select()    ));
	connect( in_workspace, SIGNAL( unselect_right() ), d_view      , SLOT( slot_unselect()  ));
	connect( in_workspace, SIGNAL( revers_right()   ), d_view      , SLOT( slot_revers()    ));
	connect( d_view      , SIGNAL( ftp_rejected()   ), in_workspace, SIGNAL( ftp_rejected() ));
	// Obsluga klawiszy funkcyjnych.
	connect( in_workspace, SIGNAL( F2ToRight() ), d_view, SLOT( F2() ));
	connect( in_workspace, SIGNAL( F3ToRight() ), d_view, SLOT( F3() ));
	connect( in_workspace, SIGNAL( F4ToRight() ), d_view, SLOT( F4() ));
	connect( in_workspace, SIGNAL( F6ToRight() ), d_view, SLOT( F6() ));
	connect( in_workspace, SIGNAL( F7ToRight() ), d_view, SLOT( F7() ));
	connect( in_workspace, SIGNAL( F8ToRight() ), d_view, SLOT( F8() ));
	// sygnaly zwrotne z context-menu
	connect( d_view, SIGNAL( F5() ), in_workspace, SLOT( slotF5() ));
	connect( d_view, SIGNAL( F9() ), in_workspace, SLOT( slotF9() ));
	connect( in_workspace, SIGNAL( update_lang() ), d_view, SLOT( lang_changed() ));
	connect( in_workspace, SIGNAL( update_selection() ), d_view, SIGNAL( selection_changed() ));
	connect( in_workspace, SIGNAL( tree_right() ), d_view, SLOT( tree() ));
	connect( in_workspace, SIGNAL( md5_create_right() ), d_view, SLOT( md5_create() ));
	connect( in_workspace, SIGNAL( md5_check_right() ), d_view, SLOT( md5_check() ));

	QString call_path = QString::null;
	for( int i = 0; i < qApp->argc(); ++i ) {
		QString arg = qApp->argv()[i];
		if( arg.startsWith( ArgPrefix ) ) {
			call_path = arg.mid( ArgPrefix.length() );
			break;
		}
	}

	if( Shared::is_dir_ok( call_path ) ) {
		d_view->disp_this_location( call_path, "" );
	}
	else {
		QString dname;
		QString fname;
		QStringList items;
		Settings::read( ConfigGroupName, d_view->CONFIG_KEY_PATH, dname );
		Settings::read( ConfigGroupName, d_view->CONFIG_KEY_FILE, fname );
		Settings::read( ConfigGroupName, d_view->CONFIG_KEY_COMBO, items );
		d_view->set_combox_items( items );
		d_view->disp_this_location( dname, fname );
	}
}
// end of RightView

//*******************************************************************
// ~RightPanel
//*******************************************************************
RightView::~RightView()
{
	Settings::save( ConfigGroupName, d_view->CONFIG_KEY_PATH, d_view->get_dir() );
	Settings::save( ConfigGroupName, d_view->CONFIG_KEY_FILE, d_view->get_current_fname() );
	Settings::save( ConfigGroupName, d_view->CONFIG_KEY_COMBO, d_view->get_combox_items() );
}
// end of ~RightView

//*******************************************************************
// has_focus                                                  PUBLIC
//-------------------------------------------------------------------
// Funkcja PRZEKAZNIKOWA przenoszaca informacje, czy tabela jest
// aktywna (czy ma focus).
// (ViewTable->ViewWindow->RightView->Workspace)
//*******************************************************************
bool RightView::has_focus() const
{
	return ( d_view ? d_view->has_focus() : FALSE );
}
// end of has_focus
